@@ -18,7 +18,7 @@
  *      along with this program; if not, write to the Free Software
  *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: document.h 4928 2010-05-16 17:45:39Z eht16 $
+ *  $Id: document.h 5430 2010-11-23 16:23:22Z ntrel $
  */
 
 /**
@@ -43,6 +43,7 @@
 #endif
 
 
+/** File Prefs. */
 typedef struct GeanyFilePrefs
 {
 	gint			default_new_encoding;
@@ -58,6 +59,8 @@ typedef struct GeanyFilePrefs
 	gint			disk_check_timeout;
 	gboolean		cmdline_new_files;	/* New file if command-line filename doesn't exist */
 	gboolean		use_safe_file_saving;
+	gboolean		ensure_convert_new_lines;
+	gboolean		gio_unsafe_save_backup;
 }
 GeanyFilePrefs;
 
