@@ -6,19 +6,19 @@ comment=comment
 commentline=comment
 commentdoc=commentdoc
 number=number
-word=word
-word2=word2
+word=keyword
+word2=keyword2
 string=string
 character=string
-uuid=0x404080
+uuid=extra
 preprocessor=preprocessor
 operator=operator
 identifier=default
 stringeol=stringeol
 # @"verbatim"
-verbatim=0x101030
+verbatim=extra
 # (/regex/)
-regex=0x105090
+regex=extra
 commentlinedoc=commentdoc,bold
 commentdockeyword=commentdoc,bold,italic
 commentdockeyworderror=commentdoc
@@ -26,7 +26,7 @@ globalclass=type
 
 [keywords]
 primary=abstract assert break case catch class const continue default do else extends final finally for future generic goto if implements import inner instanceof interface native new outer package private protected public rest return static super switch synchronized this throw throws transient try var volatile while true false null
-secondary=boolean byte char double float int long null short void
+secondary=boolean byte char double float int long short void
 # documentation keywords for javadoc
 doccomment=author deprecated exception param return see serial serialData serialField since throws todo version
 typedefs=
@@ -34,7 +34,7 @@ typedefs=
 
 [settings]
 # default extension used when saving files
-#extension=java
+extension=java
 
 # the following characters are these which a "word" can contains, see documentation
 #wordchars=_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789
