@@ -7,7 +7,7 @@ phpscript.mode=1
 
 [settings]
 # default extension used when saving files
-#extension=php
+extension=php
 
 # the following characters are these which a "word" can contains, see documentation
 #wordchars=_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789
@@ -28,6 +28,10 @@ comment_use_indent=true
 # context action command (please see Geany's main documentation for details)
 context_action_cmd=
 
+# if this setting is set to true, a new line after a line ending with an
+# unclosed tag will be automatically indented
+xml_indent_tags=true
+
 [build_settings]
 # %f will be replaced by the complete filename
 # %e will be replaced by the filename without extension
